# frozen_string_literal: true

#
# Cookbook:: snu_nginx_fips
# Library:: resource/snu_nginx_fips_app_debian
#
# Copyright:: 2017, Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require_relative 'snu_nginx_fips_app'

class Chef
  class Resource
    #
    # An implementation of the snu_nginx_fips_app resource for Debian platforms.
    #
    class SnuNginxFipsAppDebian < SnuNginxFipsApp
      provides :snu_nginx_fips_app_debian
      provides :snu_nginx_fips_app, platform_family: 'debian'

      #
      # The only difference between the :install and :upgrade actions is the
      # action they pass to the underlying package resource.
      #
      %i[install upgrade].each do |act|
        action act do
          apt_update 'default'
          package %w[apt-transport-https ca-certificates gnupg]

          # Use a file resource instead of apt_preference so we can avoid the
          # dep on either the apt cookbook or Chef 13.3.
          file '/etc/apt/preferences.d/nginx.pref' do
            owner 'root'
            group 'root'
            mode '0644'
            content <<-CONTENT.gsub(/^ +/, '')
              Package: nginx
              Pin: release o=Bintray, c=nginx-fips
              Pin-Priority: 700
            CONTENT
          end

          apt_repository 'snu_nginx_fips' do
            uri 'https://dl.bintray.com/socrata/nginx-fips-deb'
            distribution 'generic'
            components %w[nginx-fips]
            key 'https://bintray.com/user/downloadSubjectPublicKey?username=socrata'
          end

          package 'nginx' do
            # options '-t nginx-fips'
            version new_resource.version if new_resource.version
            action new_resource.version.nil? ? act : [act, :lock]
          end
        end
      end

      #
      # Purge the Nginx package and delete the dedicated APT repo and prefs
      # file.
      #
      action :remove do
        package('nginx') { action %i[unlock purge] }
        apt_repository('snu_nginx_fips') { action :remove }
        file('/etc/apt/preferences.d/nginx.pref') { action :delete }
      end
    end
  end
end
