# frozen_string_literal: true

#
# Cookbook:: snu_nginx_fips
# Library:: resource/snu_nginx_fips_app_rhel
#
# Copyright:: 2017, Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require_relative 'snu_nginx_fips_app'

class Chef
  class Resource
    #
    # An implementation of the snu_nginx_fips_app resource for RHEL platforms.
    #
    class SnuNginxFipsAppRhel < SnuNginxFipsApp
      provides :snu_nginx_fips_app_rhel
      provides :snu_nginx_fips_app, platform_family: 'rhel'

      #
      # The only difference between the :install and :upgrade actions is the
      # action they pass to the underlying package resource.
      #
      %i[install upgrade].each do |act|
        action act do
          yum_repository 'snu_nginx_fips' do
            description 'The Nginx web server running in FIPS mode'
            baseurl 'https://dl.bintray.com/socrata/nginx-fips-rpm/el/' \
                    '$releasever/$basearch/'
            gpgkey 'https://bintray.com/user/downloadSubjectPublicKey?' \
                   'username=socrata'
            repo_gpgcheck true
            gpgcheck false
          end

          package 'yum-plugin-versionlock'

          package 'nginx' do
            options '--enablerepo=snu_nginx_fips'
            if new_resource.version
              version "#{new_resource.version}." \
                      "el#{node['platform_version'].to_i}"
            end
            action new_resource.version.nil? ? act : [act, :lock]
          end
        end
      end

      #
      # Purge the Nginx package and delete the dedicated APT repo and prefs
      # file.
      #
      action :remove do
        package('nginx') { action %i[unlock remove] }
        yum_repository('snu_nginx_fips') { action :delete }
      end
    end
  end
end
